/**
 * Copyright (C) 2007 - Bull S.A.S.
 *
 * CAROL: Common Architecture for RMI ObjectWeb Layer
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JInitInfoWrapper.java 1272 2007-09-11 11:43:56Z loris $
 * --------------------------------------------------------------------------
 */

package org.ow2.carol.rmi.jrmp.interceptor.wrapper;

import org.ow2.carol.rmi.jrmp.interceptor.api.JDuplicateName;
import org.ow2.carol.rmi.jrmp.interceptor.api.JInitInfo;
import org.ow2.carol.rmi.jrmp.interceptor.spi.JClientRequestInterceptor;
import org.ow2.carol.rmi.jrmp.interceptor.spi.JServerRequestInterceptor;


@SuppressWarnings("deprecation")
final class JInitInfoWrapper implements org.objectweb.carol.rmi.jrmp.interceptor.JInitInfo {

    private final JInitInfo newJinit;

    JInitInfoWrapper(JInitInfo newJinit) {
        this.newJinit = newJinit;
    }

    public void add_client_request_interceptor(
            org.objectweb.carol.rmi.jrmp.interceptor.JClientRequestInterceptor interceptor)
    throws org.objectweb.carol.rmi.jrmp.interceptor.JDuplicateName {
        try {
            newJinit.add_client_request_interceptor(new JClientRequestInterceptorWrapper(interceptor));
        } catch (JDuplicateName e) {
            throw new org.objectweb.carol.rmi.jrmp.interceptor.JDuplicateName(e.getCause());
        }
    }

    public void add_server_request_interceptor(
            org.objectweb.carol.rmi.jrmp.interceptor.JServerRequestInterceptor interceptor)
    throws org.objectweb.carol.rmi.jrmp.interceptor.JDuplicateName {
        try {
            newJinit.add_server_request_interceptor(new JServerRequestInterceptorWrapper(interceptor));
        } catch (JDuplicateName e) {
            throw new org.objectweb.carol.rmi.jrmp.interceptor.JDuplicateName(e.getCause());
        }
    }

    public org.objectweb.carol.rmi.jrmp.interceptor.JClientRequestInterceptor[] getClientRequestInterceptors() {
        JClientRequestInterceptor[] jClientRequestInterceptors = newJinit.getClientRequestInterceptors();
        org.objectweb.carol.rmi.jrmp.interceptor.JClientRequestInterceptor[] result =
            new org.objectweb.carol.rmi.jrmp.interceptor.JClientRequestInterceptor[jClientRequestInterceptors.length];
        for(int i=0; i<jClientRequestInterceptors.length; i++) {
            result[i]=new JClientRequestInterceptorWrapper(jClientRequestInterceptors[i]);
        }
        return result;
    }

    public org.objectweb.carol.rmi.jrmp.interceptor.JServerRequestInterceptor[] getServerRequestInterceptors() {
        JServerRequestInterceptor[] jServerRequestInterceptors = newJinit.getServerRequestInterceptors();
        org.objectweb.carol.rmi.jrmp.interceptor.JServerRequestInterceptor[] result =
            new org.objectweb.carol.rmi.jrmp.interceptor.JServerRequestInterceptor[jServerRequestInterceptors.length];
        for(int i=0; i<jServerRequestInterceptors.length; i++) {
            result[i]=new JServerRequestInterceptorWrapper(jServerRequestInterceptors[i]);
        }
        return result;
    }

}
