/**
 * Copyright (C) 2007 - Bull S.A.S.
 *
 * CAROL: Common Architecture for RMI ObjectWeb Layer
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JServerRequestInfoWrapper.java 1272 2007-09-11 11:43:56Z loris $
 * --------------------------------------------------------------------------
 */

package org.ow2.carol.rmi.jrmp.interceptor.wrapper;

import java.util.ArrayList;
import java.util.Collection;

import org.ow2.carol.rmi.jrmp.interceptor.api.JServerRequestInfo;
import org.ow2.carol.rmi.jrmp.interceptor.spi.JServiceContext;

@SuppressWarnings("deprecation")
final class JServerRequestInfoWrapper
implements org.objectweb.carol.rmi.jrmp.interceptor.JServerRequestInfo, JServerRequestInfo {

    private final JServerRequestInfo jri;

    private final org.objectweb.carol.rmi.jrmp.interceptor.JServerRequestInfo oldjri;


    JServerRequestInfoWrapper(JServerRequestInfo jri) {
        this.jri = jri;
        oldjri = null;
    }

    JServerRequestInfoWrapper(org.objectweb.carol.rmi.jrmp.interceptor.JServerRequestInfo jri) {
        this.jri = null;
        oldjri = jri;
    }

    public void add_all_reply_service_context(Collection c) {
        if(jri != null) {
            jri.add_all_reply_service_context((Collection<JServiceContext>) c);
        } else {
            Collection<org.objectweb.carol.rmi.jrmp.interceptor.JServiceContext> collection =
                new ArrayList<org.objectweb.carol.rmi.jrmp.interceptor.JServiceContext>();
            for(Object obj : c) {
                collection.add(new JServiceContextWrapper((JServiceContextWrapper) obj));
            }
            oldjri.add_all_reply_service_context(collection);
        }
    }

    public void add_reply_service_context(
            org.objectweb.carol.rmi.jrmp.interceptor.JServiceContext serviceContext) {
        jri.add_reply_service_context(serviceContext);
    }

    public void clearAllContexts() {
        if(jri != null) {
            jri.clearAllContexts();
        } else {
            oldjri.clearAllContexts();
        }
    }

    public Collection get_all_reply_service_context() {
        if(jri != null) {
            return jri.get_all_reply_service_context();
        } else {
            Collection<org.objectweb.carol.rmi.jrmp.interceptor.JServiceContext> collection =
                new ArrayList<org.objectweb.carol.rmi.jrmp.interceptor.JServiceContext>();
            for(Object obj : oldjri.get_all_reply_service_context()) {
                collection.add(new JServiceContextWrapper((JServiceContextWrapper) obj));
            }
            return collection;
        }
    }

    public Collection get_all_request_service_context() {
        if(jri != null) {
            return jri.get_all_request_service_context();
        } else {
            Collection<org.objectweb.carol.rmi.jrmp.interceptor.JServiceContext> collection =
                new ArrayList<org.objectweb.carol.rmi.jrmp.interceptor.JServiceContext>();
            for(Object obj : oldjri.get_all_request_service_context()) {
                collection.add(new JServiceContextWrapper((JServiceContextWrapper) obj));
            }
            return collection;
        }
    }

    public org.objectweb.carol.rmi.jrmp.interceptor.JServiceContext get_reply_service_context(int id) {
        if(jri != null) {
            return new JServiceContextWrapper(jri.get_reply_service_context(id));
        } else {
            return oldjri.get_reply_service_context(id);
        }
    }

    public org.objectweb.carol.rmi.jrmp.interceptor.JServiceContext get_request_service_context(int id) {
        if(jri != null) {
            return new JServiceContextWrapper(jri.get_request_service_context(id));
        } else {
            return oldjri.get_request_service_context(id);
        }
    }

    public boolean hasContexts() {
        if(jri != null) {
            return jri.hasContexts();
        } else {
            return oldjri.hasContexts();
        }
    }

    public void add_reply_service_context(JServiceContext serviceContext) {
        oldjri.add_reply_service_context(new JServiceContextWrapper(serviceContext));
    }

}
