/**
 * Copyright (C) 2007 - Bull S.A.S.
 *
 * CAROL: Common Architecture for RMI ObjectWeb Layer
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JServerRequestInterceptorWrapper.java 1272 2007-09-11 11:43:56Z loris $
 * --------------------------------------------------------------------------
 */

package org.ow2.carol.rmi.jrmp.interceptor.wrapper;

import java.io.IOException;

import org.ow2.carol.rmi.jrmp.interceptor.api.JServerRequestInfo;
import org.ow2.carol.rmi.jrmp.interceptor.spi.JServerRequestInterceptor;

@SuppressWarnings("deprecation")
final class JServerRequestInterceptorWrapper
implements org.objectweb.carol.rmi.jrmp.interceptor.JServerRequestInterceptor, JServerRequestInterceptor {

    private final org.objectweb.carol.rmi.jrmp.interceptor.JServerRequestInterceptor interceptor;

    private final JServerRequestInterceptor newinterceptor;

    JServerRequestInterceptorWrapper(
            org.objectweb.carol.rmi.jrmp.interceptor.JServerRequestInterceptor interceptor) {
        this.interceptor = interceptor;
        newinterceptor = null;
    }

    JServerRequestInterceptorWrapper(JServerRequestInterceptor interceptor) {
        this.interceptor = null;
        newinterceptor = interceptor;
    }

    public String name() {
        if(interceptor != null) {
            return interceptor.name();
        } else {
            return newinterceptor.name();
        }
    }

    public void receive_request(JServerRequestInfo jri) throws IOException {
        interceptor.receive_request(new JServerRequestInfoWrapper(jri));
    }

    public void send_exception(JServerRequestInfo jri) throws IOException {
        interceptor.send_exception(new JServerRequestInfoWrapper(jri));
    }

    public void send_other(JServerRequestInfo jri) throws IOException {
        interceptor.send_other(new JServerRequestInfoWrapper(jri));
    }

    public void send_reply(JServerRequestInfo jri) throws IOException {
        interceptor.send_reply(new JServerRequestInfoWrapper(jri));
    }

    public void receive_request(
            org.objectweb.carol.rmi.jrmp.interceptor.JServerRequestInfo jri)
            throws IOException {
        newinterceptor.receive_request(new JServerRequestInfoWrapper(jri));
    }

    public void send_exception(
            org.objectweb.carol.rmi.jrmp.interceptor.JServerRequestInfo jri)
            throws IOException {
        newinterceptor.send_exception(new JServerRequestInfoWrapper(jri));
    }

    public void send_other(
            org.objectweb.carol.rmi.jrmp.interceptor.JServerRequestInfo jri)
            throws IOException {
        newinterceptor.send_other(new JServerRequestInfoWrapper(jri));
    }

    public void send_reply(
            org.objectweb.carol.rmi.jrmp.interceptor.JServerRequestInfo jri)
            throws IOException {
        newinterceptor.send_reply(new JServerRequestInfoWrapper(jri));
    }

}
